@@ -1,11 +1,9 @@
-from typing import Final
-
 from discord import ApplicationContext, Bot, Cog, slash_command
 
 
 class Example(Cog):
     def __init__(self, bot: Bot) -> None:
-        self.bot: Final[Bot] = bot
+        self.bot = bot
 
     @slash_command(description="Say hello.")
     async def hello(self, ctx: ApplicationContext) -> None:
